@@ -12,7 +12,7 @@ sub setup_user_customization {
 		say "couldn't parse $filename: $@\n" if $@;
 		return;
 	}
-	logpkg(__FILE__,__LINE__,'debug','customization :', sub{yaml_out(\%custom)});
+	logpkg(__FILE__,__LINE__,'debug','customization :', sub{json_out(\%custom)});
 	my $prompt;
 	$prompt = gen_coderef('prompt', $custom{prompt}) if $custom{prompt};
 	{ no warnings 'redefine';
