@@ -60,7 +60,7 @@ sub new {
 
 	my $name = $self->host_track;
 	my $host = $Audio::Nama::tn{$name};
-	confess( Audio::Nama::project_dir().": missing host_track".  $Audio::Nama::this_track->dump. $self->dump. Audio::Nama::command_process("dumpa")) if !$host;
+	confess( Audio::Nama::project_dir().": missing host_track".  $Audio::Nama::this_track->dump. $self->dump. Audio::Nama::process_command("dumpa")) if !$host;
 
 # Routing:
 #
@@ -81,10 +81,12 @@ sub new {
 	Audio::Nama::Track->new(
 		name 		=> $self->edit_root_name, # i.e. sax-v5
 	#	rw			=> 'REC',                 # set by ->busify
+	#											# NOT CURRENTLY XXX
 		source_type => 'bus',
 		source_id 	=> 'bus',
 		width		=> 2,                     # default to stereo 
 	#	rec_defeat 	=> 1,                     # set by ->busify
+	#											# NOT CURRENTLY XXX
 		group   	=> $self->host_track,     # i.e. sax
 		hide		=> 1,
 	); 
@@ -815,33 +817,6 @@ sub merge_edits {
 	$this_track = $edit->host;
 	
 }
-sub show_version_comments {
-	my ($t, @v) = @_;
-	return unless @v;
-	Audio::Nama::pager(map{ $t->version_comment($_) } @v);
-}
-sub add_version_comment {
-	my ($t,$v,$text) = @_;
-	$t->targets->{$v} or say("$v: no such version"), return;	
-	$t->{version_comment}{$v}{user} = $text;
-	$t->version_comment($v);
-}
-sub add_system_version_comment {
-	my ($t,$v,$text) = @_;
-	$t->targets->{$v} or say("$v: no such version"), return;	
-	$t->{version_comment}{$v}{system} = $text;
-	$t->version_comment($v);
-}
-sub remove_version_comment {
-	my ($t,$v) = @_;
-	$t->targets->{$v} or say("$v: no such version"), return;	
-	delete $t->{version_comment}{$v}{user};
-	$t->version_comment($v) || "$v: [comment deleted]\n";
-}
-sub remove_system_version_comment {
-	my ($t,$v) = @_;
-	delete $t->{version_comment}{$v}{system} if $t->{version_comment}{$v}
-}
 # offset recording
 
 # Note that although we use ->adjusted_* methods, all are
@@ -891,7 +866,7 @@ sub select_edit_track {
 	print("You need to select an edit first (list_edits, select_edit)\n"),
 		return unless defined $this_edit;
 	$this_track = $this_edit->$track_selector_method; 
-	command_process('show_track');
+	process_command('show_track');
 }
 
 } # end package
